@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 use warnings::register;
-our $VERSION = '1.38';
+our $VERSION = '1.39';
 require Exporter;
 require Cwd;
 
@@ -839,6 +839,9 @@ where C<find()> works from the top of the tree down.
 
 =back
 
+Despite the name of the C<finddepth()> function, both C<find()> and
+C<finddepth()> perform a depth-first search of the directory hierarchy.
+
 =head2 %options
 
 The first argument to C<find()> is either a code reference to your
@@ -848,7 +851,7 @@ code reference is described in L</The wanted function> below.
 
 Here are the possible keys for the hash:
 
-=over 3
+=over 4
 
 =item C<wanted>
 
@@ -892,7 +895,7 @@ This might be expensive both in space and time for a large
 directory tree. See L</follow_fast> and L</follow_skip> below.
 If either I<follow> or I<follow_fast> is in effect:
 
-=over 6
+=over 4
 
 =item *
 
@@ -1079,9 +1082,9 @@ situations. You can disable these warnings by putting the statement
 in the appropriate scope. See L<warnings> for more info about lexical
 warnings.
 
-=head1 CAVEAT
+=head1 BUGS AND CAVEATS
 
-=over 2
+=over 4
 
 =item $dont_use_nlink
 
@@ -1107,12 +1110,6 @@ in an unknown directory.
 
 =back
 
-=head1 BUGS AND CAVEATS
-
-Despite the name of the C<finddepth()> function, both C<find()> and
-C<finddepth()> perform a depth-first search of the directory
-hierarchy.
-
 =head1 HISTORY
 
 File::Find used to produce incorrect results if called recursively.
